import CryptoJS from 'crypto-js';
import FastScanner from './libs/fastscan';

/**
 * 随机数
 * @param range 范围
 * @returns {number}
 */
export const MathRandom = (range = 10) => {
    return Math.floor(Math.random() * range);
};
/**
 * 
 * @param {number} len 随机数求和长度
 */
export const MathRand = (len = 1) => {
    let num = "";
    for (let i = 0; i < len; i++) {
        num += Math.floor(Math.random() * 10);
    }
    return num;
};

/**
 * 转为Base64的字符串
 * CryptoJS.enc.Utf8.parse  转为128bit的字符串
 * @returns {string}
 */
export const Base64 = (data) => {
    return CryptoJS.enc.Base64.stringify(CryptoJS.enc.Utf8.parse(data));
};

/**
 * md5加密
 * @returns {string}
 */
export const MD5 = (data) => {
    return CryptoJS.MD5(data).toString();
};

/**
 * 3des加密
 * @returns {string}
 */
export const DESencrypt = (data, key) =>{
    return CryptoJS.TripleDES.encrypt(
        data,
        CryptoJS.enc.Utf8.parse(key),
        {
            mode: CryptoJS.mode.ECB,
            padding: CryptoJS.pad.Pkcs7
        }
    ).toString();
};

/**
 * 3des解密
 * @returns {string}
 */
export const DESdecrypt = (data, key) => {
    return CryptoJS.TripleDES.decrypt(
        {
            ciphertext: CryptoJS.enc.Base64.parse(data)
        },
        CryptoJS.enc.Utf8.parse(key),
        {
            mode: CryptoJS.mode.ECB,
            padding: CryptoJS.pad.Pkcs7
        }
    ).toString(CryptoJS.enc.Utf8);
};
// 防抖
export const debounce = (fn, wait) => {
    var timeout = null;
    return function() {
        if(timeout !== null) clearTimeout(timeout);
        timeout = setTimeout(fn, wait);
    }
}
// 节流
export const throttle = (fn, delay) => {
    var prev = Date.now();
    return function() {
        var context = this;
        var args = arguments;
        var now = Date.now();
        if (now - prev >= delay) {
            fn.apply(context, args);
            prev = Date.now();
        }
    }
}

//四舍五入保留2位小数（若第二位小数为0，则保留一位小数）
export const keepTwoDecimal = (num) => {
    var result = parseFloat(num);
    if (isNaN(result)) {
        console.log('传递参数错误，请检查！');
        return false;
    }
    result = Math.round(num * 100) / 100;
    return result;
}

//四舍五入保留2位小数（不够位数，则用0替补）
export const keepTwoDecimalFull = (num) => {
    var result = parseFloat(num);
    if (isNaN(result)) {
        console.log('传递参数错误，请检查！');
        return false;
    }
    result = Math.round(num * 100) / 100;
    var s_x = result.toString();
    var pos_decimal = s_x.indexOf('.');
    if (pos_decimal < 0) {
        pos_decimal = s_x.length;
        s_x += '.';
    }
    while (s_x.length <= pos_decimal + 2) {
        s_x += '0';
    }
    return s_x;
}

// 显示销量的文本
export const showSaleNumText = (num) => {
    let baseNum_wan = 10000
    let baseNum_sw = 100000
    let baseNum_bw = 1000000
    let baseNum_qw = 10000000
    let baseNum_y = 100000000
    let baseNum_sy = 1000000000
    let baseNum_by = 10000000000
    let baseNum_qy = 100000000000
    let baseNum_wy = 1000000000000
    if (num >= baseNum_wan) {
        return `${(num / baseNum_wan).toFixed(2)}万`
    }
    if (num >= baseNum_sw) {
        return `${(num / baseNum_sw).toFixed(2)}十万`
    }
    if (num >= baseNum_bw) {
        return `${(num / baseNum_bw).toFixed(2)}百万`
    }
    if (num >= baseNum_qw) {
        return `${(num / baseNum_qw).toFixed(2)}千万`
    }
    if (num >= baseNum_y) {
        return `${(num / baseNum_y).toFixed(2)}亿`
    }
    if (num >= baseNum_sy) {
        return `${(num / baseNum_sy).toFixed(2)}十亿`
    }
    if (num >= baseNum_by) {
        return `${(num / baseNum_by).toFixed(2)}百亿`
    }
    if (num >= baseNum_qy) {
        return `${(num / baseNum_qy).toFixed(2)}千亿`
    }
    if (num >= baseNum_wy) {
        return `${(num / baseNum_wy).toFixed(2)}万亿`
    }
    return num
}
// 敏感词汇屏蔽为 ****
const sensitiveWords = (offWords = [], _content = '') => {
    if (offWords.length === 0 || _content === '') return _content
    let str = '**********'
    offWords.forEach(([key, value]) => {
        _content = _content.replace(value, str.substring(0,value.length > str.length ? str.length : value.length))
    });
    return _content
}

// 查找敏感词
export const ScanSensitiveWords = (content = '') => {
    let _content = content
    let scanner = new FastScanner(sensitiveDectionary)
    let offWords = scanner.search(_content)
    console.log('offWords',offWords)
    return sensitiveWords(offWords,_content)
}
// 计算时差

export const getDiffTime = (endDate) =>{
    let diff = (Date.parse(new Date(endDate)) - Date.parse(new Date())) / 1000;
  
    if (diff <= 0) {
      return false;
    }
  
    const timeLeft = {
      years: 0,
      days: 0,
      hours: 0,
      min: 0,
      sec: 0,
      millisec: 0,
    };
  
    if (diff >= (365.25 * 86400)) {
      timeLeft.years = Math.floor(diff / (365.25 * 86400));
      diff -= timeLeft.years * 365.25 * 86400;
    }
    if (diff >= 86400) {
      timeLeft.days = Math.floor(diff / 86400);
      diff -= timeLeft.days * 86400;
    }
    if (diff >= 3600) {
      timeLeft.hours = Math.floor(diff / 3600);
      diff -= timeLeft.hours * 3600;
    }
    if (diff >= 60) {
      timeLeft.min = Math.floor(diff / 60);
      diff -= timeLeft.min * 60;
    }
    timeLeft.sec = diff;
    return timeLeft;
}
export const RandomColor = () => {
  var r = Math.floor(Math.random()*256);
  var g = Math.floor(Math.random()*256);
  var b = Math.floor(Math.random()*256);
  return "rgb("+r+","+g+","+b+")";
};

export default {
    ScanSensitiveWords, // 查找敏感词 敏感词汇屏蔽为 ****
    showSaleNumText, // 显示销量的文本
    keepTwoDecimalFull, // 四舍五入保留2位小数（不够位数，则用0替补）
    keepTwoDecimal, // 四舍五入保留2位小数（若第二位小数为0，则保留一位小数）
    throttle, // 节流
    debounce, // 防抖
    DESdecrypt, // 3des解密
    DESencrypt, // 3des加密
    MD5, // md5加密
    Base64, // 转为Base64的字符串v
    MathRand, // 获取一定长度的随机数和
    MathRandom, // 获取随机数
    getDiffTime, // 计算时差
    RandomColor, // 随机颜色
}